@@ -70,7 +70,7 @@ class FolderViewScreenlet(screenlets.Screenlet):
 	"""Display the content of a folder."""
 	# default meta-info for Screenlets
 	__name__ = 'FolderView'
-	__version__ = '0.9.91+++'
+	__version__ = '0.9.92'
 	__author__ = 'Helder Fraga aka Whise'
 	__desc__ = __doc__
 
@@ -637,14 +637,14 @@ class FolderViewScreenlet(screenlets.Screenlet):
 		ico = ''
 		exe = ''
 		for line in tmp:
-			if line.startswith(_('Icon=')):
-				ico = line.replace(_('Icon='),'').replace('\n','')
+			if line.startswith('Icon='):
+				ico = line.replace('Icon=','').replace('\n','')
 
-			elif line.startswith(_('Exec=')):
-				exe = line.replace(_('Exec='),'').replace('\n','')
+			elif line.startswith('Exec='):
+				exe = line.replace('Exec=','').replace('\n','')
 
-			elif line.startswith(_('Name=')):
-				name = line.replace(_('Name='),'').replace('\n','')
+			elif line.startswith('Name='):
+				name = line.replace('Name=','').replace('\n','')
 			
 
 		return ico,exe,name
@@ -1236,7 +1236,7 @@ class FolderViewScreenlet(screenlets.Screenlet):
 				else: 
 					self.y_position = int(self.y_position) + 1
 			ico = self.generate_icon_names(elem)
-			if os.path.isfile(ico):
+			if ico is not None and os.path.isfile(ico):
 			#if ico.lower().endswith('png') or ico.lower().endswith('svg') or ico.lower().endswith('xpm'):#xpm",
 				w,h = self.get_image_size(ico)
 				if int(w) != int(h):
@@ -1269,7 +1269,7 @@ class FolderViewScreenlet(screenlets.Screenlet):
 					self.draw_icon(self.ctx_fore, 						# self.ctx_fore
 						self.get_x(elem) + self.icon_size * 0.5 ,	# x
 						self.get_y(elem) + self.icon_size * 0.2,		# y
-						gtk.STOCK_MISSING_IMAGE, 			# icon name
+						"image-missing", 			# icon name
 						self.icon_size, self.icon_size)	
 
 			#Draw the text
@@ -1327,13 +1327,13 @@ class thumbnailengine(gobject.GObject):
 		self.thumbFactory = gnome.ui.ThumbnailFactory(gnome.ui.THUMBNAIL_SIZE_LARGE)
 		self.WorkList = []
 		self.DoneList = []
-		self.stockimage = gtk.STOCK_MISSING_IMAGE 
+		self.stockimage = "image-missing" 
 		self.Timer = None
 		
 	def lookup(self, uri):
 		icon = self.thumbFactory.lookup(uri,0)
 		if not icon:
-			icon = gtk.STOCK_MISSING_IMAGE
+			icon = "image-missing"
 		return icon
 			
 	def Process(self,uri,mime_type):
@@ -1347,7 +1347,7 @@ class thumbnailengine(gobject.GObject):
 					self.thumbFactory.save_thumbnail(thumbnail, uri, 0)
 			icon = uri
 		else:
-			icon = gtk.STOCK_MISSING_IMAGE
+			icon = "image-missing"
 		return icon
 		
 	def ProcessWorkList(self):
