@@ -33,7 +33,6 @@ from screenlets.options import IntOption, BoolOption, StringOption
 from screenlets.options import FontOption, ColorOption
 
 import gtk
-from PIL import Image
 import os
 from gtk import gdk
 import cairo
@@ -560,6 +559,7 @@ class LipikScreenlet (screenlets.Screenlet):
 	def on_draw_shape (self,ctx):
 		#set scale
 		ctx.scale(self.scale, self.scale)
+		ctx.translate(0, 1)
 		# just render bg
 		if self.theme:
 			#self.theme["note-bg.svg"].render_cairo(ctx)
