@@ -23,7 +23,7 @@
 
 
 import screenlets
-from screenlets.options import StringOption , BoolOption , IntOption, ColorOption, FontOption, ImageOption
+from screenlets.options import StringOption , BoolOption , IntOption, ColorOption, FontOption, ImageOption, ListOption
 from screenlets import DefaultMenuItem
 from screenlets import sensors
 import pango
@@ -47,7 +47,7 @@ class SysmonitorScreenlet (screenlets.Screenlet):
 	
 	# default meta-info for Screenlets (should be removed and put into metainfo)
 	__name__	= 'SysmonitorScreenlet'
-	__version__	= '0.1.7++'
+	__version__	= '0.1.8'
 	__author__	= 'Whise'
 	__desc__	= __doc__	# set description to docstring of class
 	
@@ -67,9 +67,9 @@ class SysmonitorScreenlet (screenlets.Screenlet):
 	distro = ''
 	avg_load = ''
 	cpu_nb = 0
-	old_cpu = [0,0,0,0]
-	new_cpu = [0,0,0,0]
-	cpu_load = [0,0,0,0]
+	old_cpu = []
+	new_cpu = []
+	cpu_load = []
 	distroshort = ''
 	cpu_name= ''
 	mem_used = 0
@@ -97,7 +97,7 @@ class SysmonitorScreenlet (screenlets.Screenlet):
 	starty = 0
 	number = 0
 	_update_interval = 1
-	font1 = 'FreeSans'
+	font = 'FreeSans'
 	image_filename = ''
 	use_bg_image = False
 	use_mil_time = True
@@ -119,7 +119,9 @@ class SysmonitorScreenlet (screenlets.Screenlet):
 	show_bat_wir = True
 	show_processes = True
 	show_uptime = True
-
+	#Interface selection
+	net_iface = 'lo'
+	net_ifaces = ['lo']
 
 
 	# constructor
@@ -130,6 +132,7 @@ class SysmonitorScreenlet (screenlets.Screenlet):
 		# set theme
 		self.get_constants()
 		self.theme_name = "default"
+		self.net_ifaces = sensors.net_get_ifaces()
 		# add option group
 		self.add_options_group(_('Sysmonitor'), _('Options ...'))
 		# add editable option to the groupSysmonitor
@@ -210,6 +213,9 @@ class SysmonitorScreenlet (screenlets.Screenlet):
 		self.add_option(BoolOption(_('Sensors'),'show_ip', 
 			self.show_ip, _('Show Ip'), 
 			_('Show Sensor')))
+		self.add_option(StringOption(_('Sensors'),'net_iface',
+			self.net_iface, _('Interface'),
+			_('Network interface'),choices=self.net_ifaces))
 		self.add_option(BoolOption(_('Sensors'),'show_updown', 
 			self.show_updown, _('Show Upload Download'), 
 			_('Show Sensor')))
@@ -252,6 +258,10 @@ class SysmonitorScreenlet (screenlets.Screenlet):
 		self.distro = sensors.sys_get_distrib_name()
 		self.distroshort = sensors.sys_get_distroshort()
 		self.cpu_nb = sensors.cpu_get_nb_cpu()
+		for i in range (0,self.cpu_nb):
+			self.new_cpu.insert(i,0)
+			self.cpu_load.insert(i,0)
+			self.old_cpu.insert(i,0)
 		self.cpu_name = sensors.cpu_get_cpu_name()
 
 	def get_variables(self):
@@ -276,7 +286,7 @@ class SysmonitorScreenlet (screenlets.Screenlet):
 
 		if self.show_mem: self.mem_used = sensors.mem_get_usage()
 		if self.show_swap: self.swap_used = sensors.mem_get_usedswap()
-		if self.show_ip: self.ip = sensors.net_get_ip()
+		if self.show_ip: self.ip = sensors.net_get_ip(self.net_iface) + " ("+self.net_iface+")"
 		if self.show_updown: 
 			self.up = sensors.net_get_updown()[0]
 			self.down = sensors.net_get_updown()[1]
@@ -415,13 +425,8 @@ class SysmonitorScreenlet (screenlets.Screenlet):
 	def on_draw (self, ctx):
 		self.get_variables()
 		# if theme is loaded
-		#self.font =  self.font.strip(' ')
-		if self.font.find(' ') != -1:
-			self.font1 =  self.font.strip().split(' ')[0]
-			try : self.fontsize = int(self.font.strip().split(' ')[2])
-			except:
-				try: self.fontsize = int(self.font.strip().split(' ')[1])
-				except : self.fontsize = 10
+		try: self.fontsize = float(self.font.strip().rsplit(' ', 1)[-1])
+		except: self.fontsize = 10
 		if self.theme:
 			# set scale rel. to scale-attribute
 			ctx.scale(self.scale, self.scale)
@@ -460,23 +465,23 @@ class SysmonitorScreenlet (screenlets.Screenlet):
 			m = self.starty
 			m = m + 15
 			if self.show_time:
-				self.draw_text(ctx, ' ' + self.time, 0, m, self.font1, self.fontsize + 8,  self.width,pango.ALIGN_CENTER)
+				self.draw_text(ctx, ' ' + self.time, 0, m, self.font, self.fontsize + 8,  self.width,pango.ALIGN_CENTER)
 				m = m + 30
 			if self.show_date:
-				self.draw_text(ctx, self.date, 0, m, self.font1, self.fontsize,  self.width,pango.ALIGN_CENTER)
+				self.draw_text(ctx, self.date, 0, m, self.font, self.fontsize,  self.width,pango.ALIGN_CENTER)
 				m = m + 40
 			if self.show_username:
 
-				self.draw_text(ctx, self.username + '@' + self.hostname, 0, m, self.font1, self.fontsize + 1,  self.width,pango.ALIGN_CENTER)
+				self.draw_text(ctx, self.username + '@' + self.hostname, 0, m, self.font, self.fontsize + 1,  self.width,pango.ALIGN_CENTER)
 				m = m + 25
 			if self.show_distro:
-				self.draw_text(ctx, self.distro, 0, m, self.font1, self.fontsize + 1,  self.width,pango.ALIGN_CENTER)
+				self.draw_text(ctx, self.distro, 0, m, self.font, self.fontsize + 1,  self.width,pango.ALIGN_CENTER)
 				m = m + 30
 			if self.show_kernel:
-				self.draw_text(ctx, 'kernel: ' + self.kernel, 0, m, self.font1, self.fontsize,  self.width,pango.ALIGN_CENTER)
+				self.draw_text(ctx, 'kernel: ' + self.kernel, 0, m, self.font, self.fontsize,  self.width,pango.ALIGN_CENTER)
 				m = m + 40
 			if self.show_cpuname:
-				self.draw_text(ctx, self.cpu_name, 0, m, self.font1, self.fontsize - 2,  self.width,pango.ALIGN_CENTER)
+				self.draw_text(ctx, self.cpu_name, 0, m, self.font, self.fontsize - 2,  self.width,pango.ALIGN_CENTER)
 				m = m + 35
 			if self.show_cpus:			
 				ctx.save()
@@ -492,8 +497,8 @@ class SysmonitorScreenlet (screenlets.Screenlet):
 					self.draw_rectangle(ctx,0,0,40,a)
 					ctx.translate(75,-5-(40-a))
 					ctx.set_source_rgba(self.color_text[0], self.color_text[1], self.color_text[2],self.color_text[3])
-					self.draw_text(ctx, _('CPU') , -75-70, 0, self.font1, self.fontsize,  self.width,pango.ALIGN_CENTER)
-					self.draw_text(ctx,str(self.cpu_load[0])+ '%', -75-70, 30, self.font1, self.fontsize - 2,  self.width,pango.ALIGN_CENTER)
+					self.draw_text(ctx, _('CPU') , -75-70, 0, self.font, self.fontsize,  self.width,pango.ALIGN_CENTER)
+					self.draw_text(ctx,str(self.cpu_load[0])+ '%', -75-70, 30, self.font, self.fontsize - 2,  self.width,pango.ALIGN_CENTER)
 
 					ctx.restore()
 					m = m + 40
@@ -510,8 +515,8 @@ class SysmonitorScreenlet (screenlets.Screenlet):
 					ctx.translate(75,-5-(40-a))
 					ctx.restore()
 					ctx.set_source_rgba(self.color_text[0], self.color_text[1], self.color_text[2],self.color_text[3])
-					self.draw_text(ctx, _('CPU 1') , -65, 0, self.font1, self.fontsize,  self.width,pango.ALIGN_CENTER)
-					self.draw_text(ctx,str(self.cpu_load[0])+ '%', -65, 30, self.font1, self.fontsize - 2,  self.width,pango.ALIGN_CENTER)
+					self.draw_text(ctx, _('CPU 1') , -65, 0, self.font, self.fontsize,  self.width,pango.ALIGN_CENTER)
+					self.draw_text(ctx,str(self.cpu_load[0])+ '%', -65, 30, self.font, self.fontsize - 2,  self.width,pango.ALIGN_CENTER)
 		
 					ctx.translate(75,0)
 					a = (40* self.cpu_load[1])/100
@@ -524,8 +529,8 @@ class SysmonitorScreenlet (screenlets.Screenlet):
 					self.draw_rectangle(ctx,0,0,40,a)
 					ctx.restore()
 					ctx.set_source_rgba(self.color_text[0], self.color_text[1], self.color_text[2],self.color_text[3])
-					self.draw_text(ctx, _('CPU 2') , -65, 0, self.font1, self.fontsize,  self.width,pango.ALIGN_CENTER)
-					self.draw_text(ctx,str(self.cpu_load[1])+ '%' , -65, 30, self.font1, self.fontsize - 2,  self.width,pango.ALIGN_CENTER)
+					self.draw_text(ctx, _('CPU 2') , -65, 0, self.font, self.fontsize,  self.width,pango.ALIGN_CENTER)
+					self.draw_text(ctx,str(self.cpu_load[1])+ '%' , -65, 30, self.font, self.fontsize - 2,  self.width,pango.ALIGN_CENTER)
 					#ctx.restore()
 					m = m + 40
 					d = 4
@@ -544,8 +549,8 @@ class SysmonitorScreenlet (screenlets.Screenlet):
 						ctx.translate(75,-5-(40-a))
 						ctx.restore()
 						ctx.set_source_rgba(self.color_text[0], self.color_text[1], self.color_text[2],self.color_text[3])
-						self.draw_text(ctx, _('CPU 3') , -65, 0, self.font1, self.fontsize,  self.width,pango.ALIGN_CENTER)
-						self.draw_text(ctx,str(self.cpu_load[2])+ '%', -65, 30, self.font1, self.fontsize - 2,  self.width,pango.ALIGN_CENTER)
+						self.draw_text(ctx, _('CPU 3') , -65, 0, self.font, self.fontsize,  self.width,pango.ALIGN_CENTER)
+						self.draw_text(ctx,str(self.cpu_load[2])+ '%', -65, 30, self.font, self.fontsize - 2,  self.width,pango.ALIGN_CENTER)
 
 						ctx.translate(75,0)
 						a = (40* self.cpu_load[3])/100
@@ -558,8 +563,8 @@ class SysmonitorScreenlet (screenlets.Screenlet):
 						self.draw_rectangle(ctx,0,0,40,a)
 						ctx.restore()
 						ctx.set_source_rgba(self.color_text[0], self.color_text[1], self.color_text[2],self.color_text[3])
-						self.draw_text(ctx, _('CPU 4') , -65, 0, self.font1, self.fontsize,  self.width,pango.ALIGN_CENTER)
-						self.draw_text(ctx,str(self.cpu_load[3])+ '%' , -65, 30, self.font1, self.fontsize - 2,  self.width,pango.ALIGN_CENTER)
+						self.draw_text(ctx, _('CPU 4') , -65, 0, self.font, self.fontsize,  self.width,pango.ALIGN_CENTER)
+						self.draw_text(ctx,str(self.cpu_load[3])+ '%' , -65, 30, self.font, self.fontsize - 2,  self.width,pango.ALIGN_CENTER)
 #						self.draw_rounded_rectangle(ctx,0,0,10,50,50)
 						ctx.restore()
 						m = m + 40
@@ -568,12 +573,12 @@ class SysmonitorScreenlet (screenlets.Screenlet):
 			else: m = m + 10
 			if self.show_load:
 				ctx.set_source_rgba(self.color_text[0], self.color_text[1], self.color_text[2],self.color_text[3])
-				self.draw_text(ctx, _('Load : ') + self.avg_load, 0, m, self.font1, self.fontsize,  self.width,pango.ALIGN_CENTER)
+				self.draw_text(ctx, _('Load : ') + self.avg_load, 0, m, self.font, self.fontsize,  self.width,pango.ALIGN_CENTER)
 				m = m +20
 			if self.show_mem:
 				ctx.save()
 				ctx.set_source_rgba(self.color_text[0], self.color_text[1], self.color_text[2],self.color_text[3])
-				self.draw_text(ctx, _('Ram ') + str(self.mem_used) + '%', 0, m, self.font1, self.fontsize,  self.width,pango.ALIGN_CENTER)
+				self.draw_text(ctx, _('Ram ') + str(self.mem_used) + '%', 0, m, self.font, self.fontsize,  self.width,pango.ALIGN_CENTER)
 				ctx.translate(0,m)
 				ctx.translate(20,15)
 				ctx.set_source_rgba(self.color_background[0], self.color_background[1], self.color_background[2],0.2)
@@ -586,7 +591,7 @@ class SysmonitorScreenlet (screenlets.Screenlet):
 			if self.show_swap:
 				ctx.save()
 				ctx.set_source_rgba(self.color_text[0], self.color_text[1], self.color_text[2],self.color_text[3])
-				self.draw_text(ctx,_('Swap ') + str(self.swap_used)+ "%", 0, m, self.font1, self.fontsize,  self.width,pango.ALIGN_CENTER)
+				self.draw_text(ctx,_('Swap ') + str(self.swap_used)+ "%", 0, m, self.font, self.fontsize,  self.width,pango.ALIGN_CENTER)
 				ctx.translate(0,m)
 				ctx.translate(20,15)
 				ctx.set_source_rgba(self.color_background[0], self.color_background[1], self.color_background[2],0.2)
@@ -598,13 +603,13 @@ class SysmonitorScreenlet (screenlets.Screenlet):
 				m = m +30
 			if self.show_ip:
 				ctx.set_source_rgba(self.color_text[0], self.color_text[1], self.color_text[2],self.color_text[3])
-				self.draw_text(ctx, _('IP : ') + self.ip, 0, m, self.font1, self.fontsize,  self.width,pango.ALIGN_CENTER)
+				self.draw_text(ctx, _('IP : ') + self.ip, 0, m, self.font, self.fontsize,  self.width,pango.ALIGN_CENTER)
 				m = m +25
 			if self.show_updown:
-				self.draw_text(ctx, _('Upload - ') + str(decimal.Decimal(str(self.upload)).quantize(decimal.Decimal(10)**-1)) + _(' KB/sec'), 0, m, self.font1, self.fontsize,  self.width,pango.ALIGN_CENTER)
+				self.draw_text(ctx, _('Upload - ') + str(decimal.Decimal(str(self.upload)).quantize(decimal.Decimal(10)**-1)) + _(' KB/sec'), 0, m, self.font, self.fontsize,  self.width,pango.ALIGN_CENTER)
 				m = m +20
 
-				self.draw_text(ctx, _('Download - ') + str(decimal.Decimal(str(self.download)).quantize(decimal.Decimal(10)**-1)) + _(' KB/sec'), 0, m, self.font1, self.fontsize,  self.width,pango.ALIGN_CENTER)
+				self.draw_text(ctx, _('Download - ') + str(decimal.Decimal(str(self.download)).quantize(decimal.Decimal(10)**-1)) + _(' KB/sec'), 0, m, self.font, self.fontsize,  self.width,pango.ALIGN_CENTER)
 				m = m +30
 
 			if self.show_disks:
@@ -613,7 +618,7 @@ class SysmonitorScreenlet (screenlets.Screenlet):
 					a = sensors.disk_get_usage(i)
 					if a is not None:
 						ctx.set_source_rgba(self.color_text[0], self.color_text[1], self.color_text[2],self.color_text[3])
-						self.draw_text(ctx,a[5]+  ' ' + a[4], 0, m, self.font1, self.fontsize,  self.width,pango.ALIGN_CENTER)
+						self.draw_text(ctx,a[5]+  ' ' + a[4], 0, m, self.font, self.fontsize,  self.width,pango.ALIGN_CENTER)
 						ctx.translate(0,m)
 						ctx.translate(20,15)
 						ctx.set_source_rgba(self.color_background[0], self.color_background[1], self.color_background[2],0.2)
@@ -646,9 +651,9 @@ class SysmonitorScreenlet (screenlets.Screenlet):
 					ctx.translate(75,-5-(40-a))
 					ctx.restore()
 					ctx.set_source_rgba(self.color_text[0], self.color_text[1], self.color_text[2],self.color_text[3])
-					self.draw_text(ctx, self.bat_list[0] , -65, 0, self.font1, self.fontsize,  self.width,pango.ALIGN_CENTER)
+					self.draw_text(ctx, self.bat_list[0] , -65, 0, self.font, self.fontsize,  self.width,pango.ALIGN_CENTER)
 
-					self.draw_text(ctx,str(self.bat_load) + '%', -65, 30, self.font1, self.fontsize - 2,  self.width,pango.ALIGN_CENTER)
+					self.draw_text(ctx,str(self.bat_load) + '%', -65, 30, self.font, self.fontsize - 2,  self.width,pango.ALIGN_CENTER)
 
 					ctx.translate(75,0)
 
@@ -666,29 +671,29 @@ class SysmonitorScreenlet (screenlets.Screenlet):
 					self.draw_rectangle(ctx,0,0,40,a)
 					ctx.restore()
 					ctx.set_source_rgba(self.color_text[0], self.color_text[1], self.color_text[2],self.color_text[3])
-					self.draw_text(ctx, self.wire_list[0] , -65, 0, self.font1, self.fontsize,  self.width,pango.ALIGN_CENTER)
+					self.draw_text(ctx, self.wire_list[0] , -65, 0, self.font, self.fontsize,  self.width,pango.ALIGN_CENTER)
 
-					self.draw_text(ctx,str( int(self.wire_data['percentage']))+ '%' , -65, 30, self.font1, self.fontsize - 2,  self.width,pango.ALIGN_CENTER)
+					self.draw_text(ctx,str( int(self.wire_data['percentage']))+ '%' , -65, 30, self.font, self.fontsize - 2,  self.width,pango.ALIGN_CENTER)
 					b=0
 					if str(self.bat_state) == 'discharging':
 						b=5
 						bat_remaining = float(self.bat_current)/float(self.bat_rate)
 						ctx.translate(-35,15)
-						self.draw_text(ctx,str(int(bat_remaining)) + _(' hours ') + str(int(bat_remaining * 60 % 60)) + _(' minutes'), -65, 30, self.font1, self.fontsize-2,self.width,pango.ALIGN_CENTER)
+						self.draw_text(ctx,str(int(bat_remaining)) + _(' hours ') + str(int(bat_remaining * 60 % 60)) + _(' minutes'), -65, 30, self.font, self.fontsize-2,self.width,pango.ALIGN_CENTER)
 					ctx.restore()
 					m=m+b	
 				m = m + 60
 			if self.show_processes:
-				self.draw_text(ctx,str( sensors.process_get_top().replace(' ','-')) , 0, m, self.font1, self.fontsize - 3,  self.width -10,pango.ALIGN_CENTER)
+				self.draw_text(ctx,str( sensors.process_get_top().replace(' ','-')) , 0, m, self.font, self.fontsize - 3,  self.width -10,pango.ALIGN_CENTER)
 				m = m + 150
 			if self.show_uptime:
-				self.draw_text(ctx,_('Uptime: ') + str( sensors.sys_get_uptime()) , 0, m, self.font1, self.fontsize +5,  self.width -10,pango.ALIGN_CENTER)
+				self.draw_text(ctx,_('Uptime: ') + str( sensors.sys_get_uptime()) , 0, m, self.font, self.fontsize +5,  self.width -10,pango.ALIGN_CENTER)
 			m = m + 40
 			if self.height != m and self.expand == False:
 				self.height = m
-#							ctx.translate(-20,-15)self.draw_text(ctx, self.theme_name, 0, 50, self.font1, self.fontsize,  self.width,pango.ALIGN_LEFT)
+#							ctx.translate(-20,-15)self.draw_text(ctx, self.theme_name, 0, 50, self.font, self.fontsize,  self.width,pango.ALIGN_LEFT)
 
-#			self.draw_text(ctx, 'mouse x ' + str(self.mousex ) + ' \n mouse y ' + str(self.mousey ) , 0, 170, self.font1, self.fontsize,  self.width,pango.ALIGN_LEFT)
+#			self.draw_text(ctx, 'mouse x ' + str(self.mousex ) + ' \n mouse y ' + str(self.mousey ) , 0, 170, self.font, self.fontsize,  self.width,pango.ALIGN_LEFT)
 
 
 			# render svg-file
